.. include:: substitutions.rst

.. _check-page:

**************
Check the code
**************

Geniac comes with a Command Line Interface (CLI). The :ref:`cli-page` offers a lot of functionalies. In particular, you can :ref:`cli-lint` to ensure that the guidelines to :ref:`process-page` have been correctly implemented.
